Plugins and related software — DistKV 0.52.0 documentation

# Plugins and related software

Additions to this list will be appreciated!

## Home Assistant

`Home Assistant`__ is a front-end for home automation. (Actually it’s more than that, but `distkv` uses it as a front-end and prefers to do the automation part itself.)

distkv-hass documents how to connect Home Assistant to the `distkv` system and helps with creating the data structures that teach Home Assistant about distkv-controlled sensors and actors.

## KNX

KNX is a serial bus for building control.

knxd is a server commonly used to talk to KNX interfaces.

xknx is a Python package you can use to talk to `knxd`.

distkv-knx connects values stored in distkv to devices on the KNX bus.

## 1wire

1wire is a two- or three-wire bus (one signal wire, somewhat-optional 5V power, ground) that is frequently used to connect inexpensive sensors and actors to a computer.

OWFS is the server commonly used on Linux systems to talk to 1wire.

asyncowfs is a Python package that provides a high-level object-oriented async interface to OWFS.

distkv-owfs uses `asyncowfs` to connect values stored in `distkv` to attributes if 1wire devices.

## Inventory Management

distkv-inv is a command-line extension that simplifies storage of hosts, networks and cables in `distkv`. It contains templating code so you can auto-create the configuration for your router (if it’s text instead of some binary format).

## Akumuli

Akumuli is a time series database.

asyncakumuli is a Python package that provides an async interface to Akumuli.

distkv-akumuli implements a background task that monitors values stored in `distkv` and mirrors them into Akumuli, thus saving their history.

## Binary I/O

asyncgpio is a Python package that provides structured access to your computer’s I/O ports.

distkv-gpio contains code that mirrors a binary value stored in `distkv` to a GPIO pin and vice versa.

## Wago I/O controllers

The German company WAGO Kontakttechnik makes the `750-*` line of extensible rugged controllers with various modules.